@@ -149,7 +149,8 @@ cNORM.GUI <- function(launch.browser=TRUE){
 #' are missing, cnorm uses k = 5 and t = 3 by default.
 #'
 #' @param raw Numeric vector of raw scores
-#' @param group Numeric vector of grouping variable, e. g. grade
+#' @param group Numeric vector of grouping variable, e. g. grade. If no group
+#' or age variable is provided, conventional norming is applied
 #' @param age Numeric vector with chronological age, please additionally specify
 #' width of window
 #' @param width Size of the moving window in case an age vector is used
@@ -183,7 +184,13 @@ cNORM.GUI <- function(launch.browser=TRUE){
 #' @examples
 #' \dontrun{
 #' # Using this function with the example dataset 'elfe'
-#' # You can use the 'getGroups()' function to set up grouping variable.
+#'
+#' # Conventional norming (no modelling over age)
+#' cnorm(raw=elfe$raw)
+#'
+#' # Continuous norming
+#' # You can use the 'getGroups()' function to set up grouping variable in case,
+#' # you have a continuous age variable.
 #' cnorm.elfe <- cnorm(raw = elfe$raw, group = elfe$group)
 #'
 #' # return norm tables including 90% confidence intervals for a
@@ -303,6 +310,23 @@ cnorm <- function(raw = NULL,
     }
   }
 
+  # conventional norming
+  else if(is.numeric(raw)&&is.null(group)&&is.null(age)){
+    if(is.null(weights))
+      data <- data.frame(raw = raw)
+    else
+      data <- data.frame(raw = raw, weights = weights)
+
+    data <- rankByGroup(data, raw=data$raw, group=FALSE, scale=scale, weights=data$weights, descend = descend, method = method)
+    data <- computePowers(data, k = k, t = t)
+    model <- bestModel(data, k = k, t = t, terms = terms, R2 = R2)
+
+    result <- list(data = data, model = model)
+    class(result) <- "cnorm"
+
+    return(result)
+  }
+
   # if no grouping variable is given
   else if(is.numeric(raw)&&is.numeric(age)&&!is.na(width)){
     if(length(raw)!=length(age)){
